pub type ItemTipOf<T, I = ()> = ItemTip<<T as Config<I>>::CollectionId, <T as Config<I>>::ItemId, <T as SystemConfig>::AccountId, BalanceOf<T, I>>;Expand description
A type alias for the tips held by a single item.
Aliased Type
struct ItemTipOf<T, I = ()> {
pub collection: <T as Config<I>>::CollectionId,
pub item: <T as Config<I>>::ItemId,
pub receiver: <T as Config>::AccountId,
pub amount: <<T as Config<I>>::Currency as Currency<<T as Config>::AccountId>>::Balance,
}Fields
collection: <T as Config<I>>::CollectionIdThe collection of the item.
item: <T as Config<I>>::ItemIdAn item of which the tip is sent for.
receiver: <T as Config>::AccountIdA sender of the tip.
amount: <<T as Config<I>>::Currency as Currency<<T as Config>::AccountId>>::BalanceAn amount the sender is willing to tip.